@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- mode:python; tab-width: 2; coding: utf-8 -*-
 
 """Sleipnir Transport constants"""
@@ -6,18 +5,21 @@
 from __future__ import absolute_import
 
 __author__           = 'Carlos Martín <cmartin@liberalia.net>'
-__version__          = '0.0.91'
-__date__             = '2011-10-05'
+__release__          = '.0'
+__version__          = '0.1' + __release__
+__date__             = '2013-7-03'
 __license__          = 'GNU General Public License, version 2'
 
 __namespace__        = "sleipnir"
 __modname__          = "transport"
 __appname__          = __namespace__ + '.' + __modname__
+
+# DOAP
 __title__            = 'Sleipnir Transport'
 __release__          = '1'
 __summary__          = 'A Wrapper around pika AMQP Library'
 __url__              = 'http://sleipnir.liberalia.net/'
-__copyright__        = '© 2011 Carlos Martín'
+__copyright__        = '© 2011-2013 Carlos Martín'
 
 __classifiers__      = [
     'Development Status :: 4 - Beta',
@@ -28,7 +30,7 @@ __classifiers__      = [
     'Topic :: Software Development',
     ]
 
-__long_description__ = """\
+__long_description__ = """
 Add Here a a description to this package
 """
 
@@ -37,7 +39,6 @@ __requires__ = [
     'anyjson                  >= 0.3.0',
     __namespace__ + '.core    >= 0.1.93',
     ]
-
 __tests_requires__ = [
     'pika                     >= 0.9.6-pre0',
     'anyjson                  >= 0.3.0',
