@@ -49,11 +49,14 @@ class ConnectionState(enum):
 
 
 class ConnectionType(enum):
-    ASYNC,     \
-    BLOCKING,  \
-    MOCK,      \
-    TORNADO,   \
-    TWISTED = xrange(0, 5)
+    AUTO_ASYNC,     \
+    AUTO_BLOCKING,  \
+    AMQP_ASYNC,     \
+    AMQP_BLOCKING,  \
+    AMQP_MOCK,      \
+    AMQP_TORNADO,   \
+    HTTP_BLOCKING,  \
+    HTTP_ASYNC = xrange(0, 8)
 
 
 class DeliveryMode(enum):
